@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-use version ; our $VERSION = qv('1.0.2');
+use version ; our $VERSION = qv('1.0.4');
 
 use autodie qw(:all);  
 no indirect ':fatal';
@@ -18,6 +18,7 @@ use VSGDR::UnitTest::TestSet::Representation;
 use VSGDR::UnitTest::TestSet::Resx;
 
 use Getopt::Euclid qw( :vars<opt_> );
+use List::MoreUtils qw{firstidx} ;
 use Data::Dumper;
 #use Smart::Comments ;
 use File::Basename;
@@ -27,6 +28,9 @@ my %ValidParserMakeArgs = ( vb  => "NET::VB"
                           , xls => "XLS"
                           , xml => "XML"
                           ) ;
+my %ValidParserMakeArgs2 = ( vb  => "NET2::VB"
+                           , cs  => "NET2::CS"
+                           ) ;                          
 
 
 ### get and validate parameters
@@ -34,6 +38,7 @@ my %ValidParserMakeArgs = ( vb  => "NET::VB"
 croak 'no input file'               unless defined($opt_infile);
 croak 'no output file'              unless defined($opt_outfile);
 
+my $version             = $opt_version ;
 
 my $inFile  = $opt_infile ;
 my $outFile = $opt_outfile ;
@@ -61,15 +66,40 @@ croak 'Output resource file cannot be written to' unless -f $outResxFile or ! -e
 ### build parsers
 
 
-my %Parsers = () ;
-$Parsers{${insfx}}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}}  } );
-$Parsers{${outsfx}} = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${outsfx}} } );
+my %Parsers            = () ;
+$Parsers{${insfx}}     = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } );
+# if input is in a .net language, add in a .net2 parser to the list
+if ( firstidx { $_ eq ${insfx} } ['cs','vb']  != -1 ) {
+    $Parsers{"${insfx}2"}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs2{${insfx}} } );
+}
+# if output is needed in ssdt unit test format  add in a .net2 parser to the list
+if ($version == 1)  {
+    $Parsers{${outsfx}}    = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${outsfx}} } );
+}
+else {
+    $Parsers{"${outsfx}2"} = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs2{${outsfx}} } );
+}
 
 ### build internal representations of input
 
 my $o_resx = VSGDR::UnitTest::TestSet::Resx->new() ;
 
-my $testSet         = $Parsers{$insfx}->deserialise($inFile);
+my $testSet         = undef ;
+eval {
+    $testSet         = $Parsers{$insfx}->deserialise($inFile);
+    } ;
+if ( not defined $testSet ) {
+    if ( exists $Parsers{"${insfx}2"}) {
+        eval {
+            $testSet         = $Parsers{$insfx}->deserialise($inFile);
+            }
+    }            
+    else {
+        croak 'Parsing failed.'; 
+    }
+}
+
+
 my $resx_data       = ''; { $/ = undef ; open (my $aa, "<", "${inpfx}.resx"); $resx_data = <$aa> ; close $aa ;} ; 
 my $rh_testScripts  = $o_resx->parse($resx_data) ; 
 
@@ -164,7 +194,14 @@ foreach my $test (@{$newTestSet->tests()}) {
 }
 
 unlink $outFile if -f $outFile ;
-$Parsers{$outsfx}->serialise($outFile,$newTestSet);
+
+if ($version == 1)  {
+    $Parsers{$outsfx}->serialise($outFile,$newTestSet);
+}
+else {
+    $Parsers{"${outsfx}2"}->serialise($outFile,$newTestSet);
+}
+
 
 my $o_resx_clone   = $o_resx->clone() ;
 unlink $outResxFile if -f $outResxFile ;
@@ -190,7 +227,7 @@ disableGDRTestCondition.pl - Disable/Enable Test Conditions in a GDR Unit Test f
 
 =head1 VERSION
 
-1.0.2
+1.0.4
 
 
 
@@ -229,6 +266,16 @@ Specify output file
 
 =over
 
+
+=item  -v[er][sion] [=]<outputversion>
+
+Output version type
+
+=for Euclid:
+    outputversion.type:    /[12]/
+    outputversion.default:  1
+
+
 =item  -e[n][able] [=]<enable_re>
 
 Specify condition name to enable ( as perl RE ) 
